@@ -1,22 +1,19 @@
     #include "person.h"                 // given earlier
+    using namespace std;
 
-    // interface functions set...()
     void Person::setName(string const &name)
     {
         d_name = name;
     }
-
     void Person::setAddress(string const &address)
     {
         d_address = address;
     }
-
     void Person::setPhone(string const &phone)
     {
         d_phone = phone;
     }
-
-    void Person::setWeight(size_t weight)
+    void Person::setMass(size_t mass)
     {
-        d_weight = weight;
+        d_mass = mass;
     }
